# 3D Detection Collection

This repository collects/re-implements 3D object detection models, including training and evaluation processes.


## Environment

It's tested in the followinng environment:

- CUDA Toolkit: 10.2
- python: 3.8
- numpy: 1.23.1
- pytorch: 1.8.2

